@@ -519,7 +519,6 @@ static void drawinputline(char *s, int p, int y, int *x);
 #define TALKLINE_PROMPT "   talk "
 static char cmdline[MAX_INPUT_STRING], talkline[MAX_INPUT_STRING];
 static int cmdlineoffset, talklineoffset;
-static int cmdlinetrunc = 0, talklinetrunc = 0;
 static char *focus; /* points to either talkline or cmdline */
 static fl_bool text2fieldinputmode = FALSE;
 
@@ -615,12 +614,13 @@ static void drawinputline(char *s, int p, int y, int *x)
 static void drawinputlines(void)
 {
   int old = drawsc->n;
+  int cmdlinetrunc = 0, talklinetrunc = 0;
 
   assert(cmdlineoffset >= 0 && cmdlineoffset <= strlen(cmdline));
   assert(talklineoffset >= 0 && talklineoffset <= strlen(talkline));
   drawscrn(dispsc->n); /* draw on whatever screen we're displaying */
   drawinputline(cmdline, cmdlineoffset, CMDLINE_Y, &cmdlinetrunc);
-  drawinputline(talkline, talklineoffset, TALKLINE_Y, &cmdlinetrunc);
+  drawinputline(talkline, talklineoffset, TALKLINE_Y, &talklinetrunc);
   drawsc->curx = INPUT_X_OFFSET + ((focus == cmdline) ?
 			   (cmdlineoffset - cmdlinetrunc) :
 			   (talklineoffset - talklinetrunc));
